Learn R Programming

pmwg (version 0.2.7)

gibbs_step: Gibbs step of the Particle Metropolis within Gibbs sampler

Description

Samples new theta_mu and theta_sig using Gibbs sampling

Usage

gibbs_step(sampler)

Value

A new sample for theta_mu, theta_sig and some new mixing weights in a list for use in the Particle Metropolis step.

Arguments

sampler

The pmwgs object from which to generate the new group parameters.