Learn R Programming

pmwg (version 0.2.7)

riwish: The Inverse Wishart Distribution

Description

Random generation from the Inverse Wishart distribution.

Usage

riwish(v, S)

Value

riwish generates one random draw from the distribution.

Arguments

v

Degrees of freedom (scalar).

S

Scale matrix \((p \times p)\).

Details

The mean of an inverse Wishart random variable with v degrees of freedom and scale matrix S is \((v-p-1)^{-1}S\).

Examples

Run this code
if (FALSE) {
draw <- riwish(3, matrix(c(1,.3,.3,1),2,2))
}

Run the code above in your browser using DataLab