powered by
Samples new theta_mu and theta_sig using Gibbs sampling
theta_mu
theta_sig
gibbs_step(sampler)
A new sample for theta_mu, theta_sig and some new mixing weights in a list for use in the Particle Metropolis step.
The pmwgs object from which to generate the new group parameters.