Takes the mean and variance for a multivariate normal distribution, as well as the number of particles to generate and return random draws from the multivariate normal if the numbers of particles is > 0, otherwise return NULL. At least one of mean or sigma must be provided.
particle_draws(n, mu, covar)If n > 0 returns n draws from the multivariate normal with mean and sigma, otherwise returns NULL
number of observations
mean vector
covariance matrix