powered by
Random generation from the Inverse Wishart distribution.
riwish(v, S)
riwish generates one random draw from the distribution.
riwish
Degrees of freedom (scalar).
Scale matrix \((p \times p)\).
The mean of an inverse Wishart random variable with v degrees of freedom and scale matrix S is \((v-p-1)^{-1}S\).
v
S
if (FALSE) { draw <- riwish(3, matrix(c(1,.3,.3,1),2,2)) }
Run the code above in your browser using DataLab